%bcond_with base_python

%define python_build_version 3.9
%define __python %{_bindir}/python%{python_build_version}

%if %{with base_python}
%define python_suffix %{expand:%%{lua: str='%{python_build_version}'; print(str:sub(1, 1))}}
%else
%define python_suffix %{expand:%%{lua: str='%{python_build_version}'; print(str:sub(1, 1) .. str:sub(3,-1))}}
%endif

%define pypi_name cryptography

Name: python%{python_suffix}-%{pypi_name}
Version: 3.4.7
Release: 1
License: MIT
Summary: Provides cryptographic recipes and primitives to Python developers.
Url: https://pypi.python.org/pypi/cryptography/

Source: https://files.pythonhosted.org/packages/source/c/%{pypi_name}/%{pypi_name}-%{version}.tar.gz

Patch0: python39-cryptography-no-rust.patch

BuildRequires: python%{python_suffix}-devel
BuildRequires: python%{python_suffix}-pip
BuildRequires: openssl-devel >= 1.1.1-5

BuildRequires: python%{python_suffix}-cffi >= 1.12

Requires: python%{python_suffix}-cffi >= 1.12

# Because python3-cryptography must be built with a version of OpenSSL that
# has ENGINE support enabled, ensure that the installed version of OpenSSL has
# engine support enabled as well.
Requires: libopenssl1_1 >= 1.1.1-5

%description
cryptography is a package which provides cryptographic recipes and primitives to
Python developers. It includes both high level recipes and low level interfaces
to common cryptographic algorithms such as symmetric ciphers, message digests,
and key derivation functions.

%prep
%setup -q -n %{pypi_name}-%{version}

%patch0 -p1

%build

export CRYPTOGRAPHY_DONT_BUILD_RUST=1

%py_build_wheel

%install
%py_install_wheel %{pypi_name}-%{version}-cp%{python_version_nodots}-cp%{python_version_nodots}-os400_powerpc64.whl

sed -i 's|pip|rpm|g' %{buildroot}%{python_sitelib}/*.dist-info/INSTALLER

%files
%defattr(-, qsys, *none)

%{python_sitelib}/cryptography*

%changelog
* Wed Jul 07 2021 Kevin Adler <kadler@us.ibm.com> - 3.4.7
- Update to 3.4.7
- Disable Rust build for now. Rust will be required after 3.4.x
- Drop unneeded deps: idna dropped in 2.5, asn1crypto dropped in 2.8, six dropped in 3.4

* Tue Jun 22 2021 Kevin Adler <kadler@us.ibm.com> - 2.8
- Port to Python 3.9
- Use macros from python-rpm-macros

* Thu Feb 27 2020 Naveen Ram <naveen.ram@ibm.com> - 2.8
- Update version to 2.8 from 2.5

* Mon Jan 20 2020 Naveen Ram <naveen.ram@ibm.com> - 2.5
- Update version to 2.5 from 2.2.2

* Wed Nov 13 2019 Mark Irish <mirish@ibm.com> - 2.2.2
- BuildRequire openssl-devel >= 1.1.1-5 to build with ENGINE support
- Require a version of libopenssl1_1 with ENGINE support

* Mon Sep 30 2019 Mark Irish <mirish@ibm.com> - 2.2.2
- Update openssl-devel version to >= 1.1.1 and requiring a version of python3-devel built with openssl >= 1.1.1

* Thu Jan 03 2019 - Kevin Adler <kadler@us.ibm.com>
- Add missing requires and word wrap description

* Thu Jan 03 2019 - Kevin Adler <kadler@us.ibm.com>
- Ensure necessary dependencies are listed
- Remove -I and --no-deps from pip install so dependencies build from yum

* Sun Aug 05 2018 - Kevin Adler <kadler@us.ibm.com>
- Set INSTALLER to be "rpm" instead of "pip"
- Add --no-index to pip, so it doesn't attempt to connect to the internet

* Tue Jul 17 2018 - Kevin Adler <kadler@us.ibm.com>
- Remove unneeded transitive dependencies

* Thu May 10 2018 - Kevin Adler <kadler@us.ibm.com>
- Initial commit
